Module runtime
Source - RuntimeData
- Project-specific data that needs to be passed from the binary
- StaticAssets
- Static assets that are bundled with the binary
- StaticScriptProvider
- Generic static script provider that lives in core
- get_static_textures
- Get static textures map (returns None if not initialized or in dev mode)
- run_dev
- Development entry point for running projects from disk with DLL hot-reloading
- run_game
- Main entry point for running a Perro game
- set_static_textures
- Initialize static textures (called once at startup in runtime mode)